@@ -7,7 +7,7 @@ from django.urls import reverse
 
 from netbox.models import NetBoxModel, NestedGroupModel
 from .choices import HardwareKindChoices, AssetStatusChoices
-from .utils import asset_clear_old_hw, get_prechange_field, get_plugin_setting, get_status_for
+from .utils import asset_clear_old_hw, asset_set_new_hw, get_prechange_field, get_plugin_setting, get_status_for
 
 
 class Asset(NetBoxModel):
@@ -150,6 +150,14 @@ class Asset(NetBoxModel):
         blank=True,
         null=True,
     )
+    delivery = models.ForeignKey(
+        help_text='Delivery this asset was part of',
+        to='netbox_inventory.Delivery',
+        on_delete=models.PROTECT,
+        related_name='assets',
+        blank=True,
+        null=True,
+    )
     purchase = models.ForeignKey(
         help_text='Purchase through which this asset was purchased',
         to='netbox_inventory.Purchase',
@@ -180,8 +188,10 @@ class Asset(NetBoxModel):
     )
 
     clone_fields = [
-        'status', 'device_type', 'module_type', 'inventoryitem_type', 'tenant', 'contact',
-        'storage_location', 'owner', 'purchase', 'warranty_start', 'warranty_end', 'comments'
+        'name', 'asset_tag', 'status', 'device_type', 'module_type',
+        'inventoryitem_type', 'owner', 'purchase', 'delivery',
+        'warranty_start', 'warranty_end', 'tenant', 'contact', 'storage_location',
+        'comments'
     ]
 
     @property
@@ -236,14 +246,11 @@ class Asset(NetBoxModel):
     def warranty_remaining(self):
         """
             How many days are left in warranty period.
-            Returns negative duration if period has not started yet
+            Returns negative duration if warranty expired
             Return None if warranty_end not defined
         """
         if self.warranty_end:
-            if self.warranty_start and self.warranty_start > date.today():
-                return date.today() - self.warranty_start
-            else:
-                return self.warranty_end - date.today()
+            return self.warranty_end - date.today()
         return None
 
     @property
@@ -263,14 +270,26 @@ class Asset(NetBoxModel):
             return self.warranty_end - self.warranty_start
         return None
 
+    @property
+    def warranty_progress(self):
+        """
+        Percentage of warranty elapsed
+        Returns > 100 if warranty has expired, < 0 if not started yet and None
+        if warranty_start or warranty_end not set.
+        """
+        if not self.warranty_start or not self.warranty_end:
+            return None
+        return int(100 * (self.warranty_elapsed / self.warranty_total))
+
     def clean(self):
+        self.clean_delivery()
         self.validate_hardware_types()
         self.validate_hardware()
         self.update_status()
         return super().clean()
 
-    def save(self, *args, **kwargs):
-        self.update_hardware_used()
+    def save(self, clear_old_hw=True, *args, **kwargs):
+        self.update_hardware_used(clear_old_hw)
         return super().save(*args, **kwargs)
 
     def validate_hardware_types(self):
@@ -314,7 +333,7 @@ class Asset(NetBoxModel):
         elif stored_status and not new_hw and old_hw:
             self.status = stored_status
 
-    def update_hardware_used(self):
+    def update_hardware_used(self, clear_old_hw=True):
         """ If assigning as device, module or inventoryitem set serial and
             asset_tag on it. Also remove them if unasigning.
         """
@@ -324,34 +343,23 @@ class Asset(NetBoxModel):
         new_hw = getattr(self, self.kind)
         old_serial = get_prechange_field(self, 'serial')
         old_asset_tag = get_prechange_field(self, 'asset_tag')
-        # device, module... needs None for unset asset_tag to enforce uniqness at DB level
-        new_asset_tag = self.asset_tag if self.asset_tag else None
-        # device, module... does not allow serial to be null
-        new_serial = self.serial if self.serial else ''
-        if not new_hw and old_hw:
-            # unassigned
+        if not new_hw and old_hw and clear_old_hw:
+            # unassigned existing asset, nothing asssigned now
             asset_clear_old_hw(old_hw)
         elif new_hw and old_hw != new_hw:
-            # assigned something, set its serial
-            if old_hw:
+            # assigned something new
+            if old_hw and clear_old_hw:
                 # but first clear previous hw data
                 asset_clear_old_hw(old_hw)
-            # if new_hw already has correct values, don't save it again
-            new_hw_save = False
-            if new_hw.serial != new_serial:
-                new_hw.serial = new_serial
-                new_hw_save = True
-            if new_hw.asset_tag != new_asset_tag:
-                new_hw.asset_tag = new_asset_tag
-                new_hw_save = True
-            if new_hw_save:
-                new_hw.save()
+            asset_set_new_hw(asset=self, hw=new_hw)
         elif self.serial != old_serial or self.asset_tag != old_asset_tag:
             # just changed asset's serial or asset_tag, update assigned hw
             if new_hw:
-                new_hw.serial = new_serial
-                new_hw.asset_tag = new_asset_tag
-                new_hw.save()
+                asset_set_new_hw(asset=self, hw=new_hw)
+
+    def clean_delivery(self):
+        if self.delivery and self.delivery.purchase != self.purchase:
+            raise ValidationError(f'Assigned delivery must belong to selected purchase ({self.purchase}).')
 
     def get_absolute_url(self):
         return reverse('plugins:netbox_inventory:asset', args=[self.pk])
@@ -459,6 +467,62 @@ class Purchase(NetBoxModel):
         return reverse('plugins:netbox_inventory:purchase', args=[self.pk])
 
 
+class Delivery(NetBoxModel):
+    """
+    Delivery is a stage in Purchase. Purchase can have multiple deliveries.
+    In each Delivery one or more Assets were delivered.
+    """
+    name = models.CharField(
+        max_length=100
+    )
+    purchase = models.ForeignKey(
+        help_text='Purchase that this delivery is part of',
+        to='netbox_inventory.Purchase',
+        on_delete=models.PROTECT,
+        related_name='orders',
+        blank=False,
+        null=False,
+    )
+    date = models.DateField(
+        help_text='Date when this delivery was made',
+        blank=True,
+        null=True,
+    )
+    receiving_contact = models.ForeignKey(
+        help_text='Contact that accepted this delivery',
+        to='tenancy.Contact',
+        on_delete=models.PROTECT,
+        related_name='deliveries',
+        blank=True,
+        null=True,
+    )
+    description = models.CharField(
+        max_length=200,
+        blank=True
+    )
+    comments = models.TextField(
+        blank=True
+    )
+
+    clone_fields = [
+        'purchase', 'date', 'receiving_contact', 'description', 'comments'
+    ]
+
+    class Meta:
+        ordering = ['purchase', 'name']
+        unique_together = (
+            ('purchase', 'name'),
+        )
+        verbose_name = 'delivery'
+        verbose_name_plural = 'deliveries'
+
+    def __str__(self):
+        return f'{self.purchase} {self.name}'
+
+    def get_absolute_url(self):
+        return reverse('plugins:netbox_inventory:delivery', args=[self.pk])
+
+
 class InventoryItemType(NetBoxModel):
     """
     Inventory Item Type is a model (make, part number) of an Inventory Item. In
