@@ -142,9 +142,9 @@ class AssetTest(
         module_type1 = ModuleType.objects.create(model='Module Type 1', manufacturer=manufacturer)
         inventoryitem_type1 = InventoryItemType.objects.create(model='II Type 1', manufacturer=manufacturer)
         site1 = Site.objects.create(name='Site 1', slug='site1')
-        device_role1 = DeviceRole.objects.create(name='Device Role 1', slug='devicerole1')
-        cls.device1 = Device.objects.create(name='Device 1', device_role=device_role1, device_type=device_type1, site=site1, status='active')
-        cls.device2 = Device.objects.create(name='Device 2', device_role=device_role1, device_type=device_type2, site=site1, status='active')
+        role1 = DeviceRole.objects.create(name='Device Role 1', slug='devicerole1')
+        cls.device1 = Device.objects.create(name='Device 1', role=role1, device_type=device_type1, site=site1, status='active')
+        cls.device2 = Device.objects.create(name='Device 2', role=role1, device_type=device_type2, site=site1, status='active')
         cls.inventoryitem1 = InventoryItem.objects.create(device=cls.device1, name='II 1')
         supplier1 = Supplier.objects.create(name='Supplier1', slug='supplier1')
         cls.purchase1 = Purchase.objects.create(name='Purchase1', supplier=supplier1)
