@@ -1,6 +1,7 @@
-from django.urls import path
+from django.urls import include, path
 
 from netbox.views.generic import ObjectChangeLogView, ObjectJournalView
+from utilities.urls import get_model_urls
 from . import models, views
 
 
@@ -22,6 +23,9 @@ urlpatterns = (
     path('assets/device/create/', views.AssetDeviceCreateView.as_view(), name='asset_device_create'),
     path('assets/module/create/', views.AssetModuleCreateView.as_view(), name='asset_module_create'),
     path('assets/inventory-item/create/', views.AssetInventoryItemCreateView.as_view(), name='asset_inventoryitem_create'),
+    path('assets/device/<int:pk>/reassign/', views.AssetDeviceReassignView.as_view(), name='asset_device_reassign'),
+    path('assets/module/<int:pk>/reassign/', views.AssetModuleReassignView.as_view(), name='asset_module_reassign'),
+    path('assets/inventoryitem/<int:pk>/reassign/', views.AssetInventoryItemReassignView.as_view(), name='asset_inventoryitem_reassign'),
 
     # Suppliers
     path('suppliers/', views.SupplierListView.as_view(), name='supplier_list'),
@@ -30,10 +34,7 @@ urlpatterns = (
     path('suppliers/edit/', views.SupplierBulkEditView.as_view(), name='supplier_bulk_edit'),
     path('suppliers/delete/', views.SupplierBulkDeleteView.as_view(), name='supplier_bulk_delete'),
     path('suppliers/<int:pk>', views.SupplierView.as_view(), name='supplier'),
-    path('suppliers/<int:pk>/edit/', views.SupplierEditView.as_view(), name='supplier_edit'),
-    path('suppliers/<int:pk>/delete/', views.SupplierDeleteView.as_view(), name='supplier_delete'),
-    path('suppliers/<int:pk>/changelog/', ObjectChangeLogView.as_view(), name='supplier_changelog', kwargs={'model': models.Supplier}),
-    path('suppliers/<int:pk>/journal/', ObjectJournalView.as_view(), name='supplier_journal', kwargs={'model': models.Supplier}),
+    path('suppliers/<int:pk>/', include(get_model_urls('netbox_inventory', 'supplier'))),
 
     # Purchases
     path('purchases/', views.PurchaseListView.as_view(), name='purchase_list'),
@@ -47,6 +48,18 @@ urlpatterns = (
     path('purchases/<int:pk>/changelog/', ObjectChangeLogView.as_view(), name='purchase_changelog', kwargs={'model': models.Purchase}),
     path('purchases/<int:pk>/journal/', ObjectJournalView.as_view(), name='purchase_journal', kwargs={'model': models.Purchase}),
 
+    # Deliveries
+    path('deliveries/', views.DeliveryListView.as_view(), name='delivery_list'),
+    path('deliveries/add/', views.DeliveryEditView.as_view(), name='delivery_add'),
+    path('deliveries/import/', views.DeliveryBulkImportView.as_view(), name='delivery_import'),
+    path('deliveries/edit/', views.DeliveryBulkEditView.as_view(), name='delivery_bulk_edit'),
+    path('deliveries/delete/', views.DeliveryBulkDeleteView.as_view(), name='delivery_bulk_delete'),
+    path('deliveries/<int:pk>', views.DeliveryView.as_view(), name='delivery'),
+    path('deliveries/<int:pk>/edit/', views.DeliveryEditView.as_view(), name='delivery_edit'),
+    path('deliveries/<int:pk>/delete/', views.DeliveryDeleteView.as_view(), name='delivery_delete'),
+    path('deliveries/<int:pk>/changelog/', ObjectChangeLogView.as_view(), name='delivery_changelog', kwargs={'model': models.Delivery}),
+    path('deliveries/<int:pk>/journal/', ObjectJournalView.as_view(), name='delivery_journal', kwargs={'model': models.Delivery}),
+
     # InventoryItemTypes
     path('inventory-item-types/', views.InventoryItemTypeListView.as_view(), name='inventoryitemtype_list'),
     path('inventory-item-types/add/', views.InventoryItemTypeEditView.as_view(), name='inventoryitemtype_add'),
