@@ -1,5 +1,7 @@
 from netbox.views import generic
+from tenancy.views import ObjectContactsView
 from utilities.utils import count_related
+from utilities.views import register_model_view
 from .. import filtersets, forms, models, tables
 
 __all__ = (
@@ -10,8 +12,10 @@ __all__ = (
     'SupplierBulkImportView',
     'SupplierBulkEditView',
     'SupplierBulkDeleteView',
+    'SupplierContactsView',
 )
 
+
 class SupplierView(generic.ObjectView):
     queryset = models.Supplier.objects.all()
 
@@ -27,11 +31,14 @@ class SupplierView(generic.ObjectView):
             'asset_table': asset_table,
             'asset_count': models.Asset.objects.filter(purchase__supplier=instance).count(),
             'purchase_count': models.Purchase.objects.filter(supplier=instance).count(),
+            'delivery_count': models.Delivery.objects.filter(purchase__supplier=instance).count(),
         }
 
+
 class SupplierListView(generic.ObjectListView):
     queryset = models.Supplier.objects.annotate(
         purchase_count=count_related(models.Purchase, 'supplier'),
+        delivery_count=count_related(models.Delivery, 'purchase__supplier'),
         asset_count=count_related(models.Asset, 'purchase__supplier'),
     )
     table = tables.SupplierTable
@@ -39,18 +46,19 @@ class SupplierListView(generic.ObjectListView):
     filterset_form = forms.SupplierFilterForm
 
 
+@register_model_view(models.Supplier, 'edit')
 class SupplierEditView(generic.ObjectEditView):
     queryset = models.Supplier.objects.all()
     form = forms.SupplierForm
 
 
+@register_model_view(models.Supplier, 'delete')
 class SupplierDeleteView(generic.ObjectDeleteView):
     queryset = models.Supplier.objects.all()
 
 
 class SupplierBulkImportView(generic.BulkImportView):
-    queryset = models.Supplier.objects.all()   
-    table = tables.SupplierTable 
+    queryset = models.Supplier.objects.all()
     model_form = forms.SupplierImportForm
 
 
@@ -64,3 +72,8 @@ class SupplierBulkEditView(generic.BulkEditView):
 class SupplierBulkDeleteView(generic.BulkDeleteView):
     queryset = models.Supplier.objects.all()
     table = tables.SupplierTable
+
+
+@register_model_view(models.Supplier, 'contacts')
+class SupplierContactsView(ObjectContactsView):
+    queryset = models.Supplier.objects.all()
